#!/bin/sh
### Copyright 1999-2012. Parallels IP Holdings GmbH. All Rights Reserved.

if [ ! -d /var/lock/files ]; then
    (mkdir -p /var/lock/files && chmod 777 /var/lock/files) >/dev/null 2>&1
fi


USAGE="Usage: $0 <port> [ipv4 | ipv6] [ none | plain | htpasswd | htdigest ]"

if [ -z "$1" ]; then
	echo $USAGE 1>&2
	exit 1
fi

PORT="$1"
shift

IPV6="no"
if [ "$1" = "ipv6" ]; then
	IPV6="yes"
	shift
elif [ "$1" = "ipv4" ]; then
	IPV6="ipv4"
	shift
fi

AUTH="none"
if [ -n "$1" ]; then
	AUTH="$1"
	shift
fi

if [ -n "$1" ] ; then
	echo "Unknown extra args: $@" 1>&2
	echo $USAGE 1>&2
	exit 1
fi

# Checking IPv6 status in system:
IPV6_SOCKET="no"

# Note: no FreeBSD support
if [ -f /proc/net/if_inet6 ] ; then
	IPV6_SOCKET="only"

	# does IPv6 socket accept IPv4 connections?
	if [ "X`/sbin/sysctl -n -e net.ipv6.bindv6only`" = "X0" ] ; then
		IPV6_SOCKET="yes"
	elif [ -d "/proc/vz" ] ; then
		# Bind only to IPv6 under Virtuozzo
		IPV6_SOCKET="yes"
	fi
fi

# IPv6 is not supported by OS settings.
if [ $IPV6 = "yes" -a $IPV6_SOCKET = "no" ] ; then
	exit 0
fi

# In that case IPv6 socket can serve IPv4 clients,
# so IPv4 section is not needed at all
if [ $IPV6 = "no" -a $IPV6_SOCKET = "yes" ] ; then
	exit 0
fi
# Otherwise, if ipv4 option was passed we generate
# config only for ipv4. No call with ipv6 is expected then.

# Define how server socket matcher looks like
if [ $IPV6_SOCKET = "only" -a $IPV6 = "yes" ]; then
	SOCK_MATCHER="[::]:$PORT"
else
	SOCK_MATCHER=":$PORT"
fi

if [ "$AUTH" != "none" ]; then
	AUTH_OPTIONS="
	auth.debug = 0
	auth.backend = \"$AUTH\"
	auth.backend.$AUTH.userfile = var.agent_auth_file
	"
	
	AUTH_REQUIRE='
		auth.require = ( "" =>
		                    (
		                        "method" => var.agent_auth_method ,
		                        "realm" => var.agent_auth_realm ,
		                        "require" => "valid-user"
		                    )
		)
		'
fi


cat <<EOF
\$SERVER["socket"] == "$SOCK_MATCHER" {
	include_shell var.agent_ssl_conf_script
	$AUTH_OPTIONS

	\$HTTP["url"] =~ "^/agent.cgi$" {
		accesslog.filename = var.agent_accesslog
		$AUTH_REQUIRE
	}

	alias.url += (
		"/agent.cgi" => var.agent_bin_path ,
	)

	cgi.assign += (
		"/agent.cgi" => "",
	)
}
EOF
