#!/bin/sh
### Copyright 1999-2012. Parallels IP Holdings GmbH. All Rights Reserved.
#
# Produces SSL configuration options for sw-cp-server Plesk remote agent configuration.
# Ensures that no collision occures with similar options used by Plesk.
#
#


if [ "`id -u`" -ne 0 ]; then
	exit 0
fi

CERT_FILE="/opt/psa_agent/internal/certificate"
CA_FILE="/opt/psa_agent/internal/rootchain.pem"
PSA_CONF="/etc/sw-cp-server/applications.d/plesk.conf"
PSA_SSL_CONF="/opt/psa/admin/conf/ssl-conf.sh"
CIPHER_FILE="/opt/psa_agent/internal/cipher.lst"

if [ -f "$PSA_CONF" -a -x "$PSA_SSL_CONF" ]; then
	conf=`$PSA_SSL_CONF`
fi

print_ifndef()
{
	local subopt="$1"
	local value="$2"
	if ! echo "$conf" | grep -q "^ssl\.$subopt" ; then
		echo "ssl.$subopt = \"$value\""
	fi
}

[ -f "$CERT_FILE" ] || exit 0

print_ifndef "engine" "enable"
print_ifndef "use-sslv2" "disable"
print_ifndef "pemfile" "$CERT_FILE"

if [ -f "$CA_FILE" ]; then
	print_ifndef "ca-file" "$CA_FILE"
	print_ifndef "verifyclient.activate" "enable"
	print_ifndef "verifyclient.enforce" "enable"
	print_ifndef "verifyclient.username" "enable"
	print_ifndef "verifyclient.exportcert" "enable"
fi

if [ -s "$CIPHER_FILE" ]; then
	print_ifndef "cipher-list" "`cat $CIPHER_FILE`"
fi

